# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .pipeline import Pipeline

__all__ = ["PipelineListResponse"]

PipelineListResponse: TypeAlias = List[Pipeline]
