# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal, TypeAlias

__all__ = ["InputType"]

InputType: TypeAlias = Literal[
    "email",
    "pdf",
    "xlsx",
    "xls",
    "docx",
    "csv",
    "text",
    "json",
    "png",
    "jpeg",
    "heic",
    "heif",
    "webp",
    "html",
    "wav",
    "mp3",
    "m4a",
]
