# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from datetime import datetime
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from .._models import BaseModel
from .task_status import TaskStatus

__all__ = ["Task"]


class Task(BaseModel):
    status: TaskStatus
    """The status of the task."""

    task_id: str = FieldInfo(alias="taskID")
    """Unique ID generated by bem following Segment's KSUID conventions."""

    type: Literal["transformation"]
    """The type of the task."""

    created_at: Optional[datetime] = FieldInfo(alias="createdAt", default=None)
    """Timestamp when task was initiated."""
