# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["TransformationCreateResponse", "Transformation"]


class Transformation(BaseModel):
    reference_id: Optional[str] = FieldInfo(alias="referenceID", default=None)
    """The unique ID you use internally to refer to this data point."""

    task_create_status: Optional[str] = None
    """Whether the task is a newly created task or a duplicate task."""

    task_id: Optional[str] = FieldInfo(alias="taskID", default=None)
    """
    Task ID generated by bem to track the status of this transformation request
    using the tasks API.
    """


class TransformationCreateResponse(BaseModel):
    transformations: Optional[List[Transformation]] = None
    """
    An array of transformations that have been created or de-duplicated by
    reference.
    """
