# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from .._models import BaseModel

__all__ = ["EventBase"]


class EventBase(BaseModel):
    event_id: str = FieldInfo(alias="eventID")
    """Unique ID generated by bem to identify the event."""

    reference_id: str = FieldInfo(alias="referenceID")
    """
    The unique ID you use internally to refer to this data point, propagated from
    the original action input.
    """
